# Introduction

The folder `asynchronous` contains the example of asynchronous execution using [Caqui](https://github.com/douglasdcm/caqui). The folder `synchronous` is the same synchronous test for performance comparison